import {FC, useEffect, useState} from "react";
import {Image, Swiper, SwiperItem, View} from "@tarojs/components";
import styles from '../home.module.scss'
import Taro from "@tarojs/taro";
import {HomeApi} from "@/api";

interface DataContent {
  id: number,
  imageUrl: string
  title: string,
  description: string
}

interface Data {
  title: string,
  url: string,
  detailsUrl: string
  data: DataContent[]
}

const FeatureRecommended: FC = () => {
  const [data, setData] = useState<Data[]>([
    {title: "品牌TOP3", url: '', detailsUrl: '', data: []},
    {title: "健康知识", url: '/pages/health/health', detailsUrl: '', data: []},
    {title: "专业技能", url: '', detailsUrl: '', data: []},
    {title: "疾病知识", url: '', detailsUrl: '', data: []},
  ])

  /** 健康知识 */
  async function getHealth() {
    const res = await HomeApi.health(1, 3)
    const oldData: Data[] = JSON.parse(JSON.stringify(data))
    if (res.data.length) {
      oldData[1].data = res.data.map<DataContent>(d => ({
        id: d.id,
        title: d.title,
        imageUrl: d.url_path,
        description: d.introduction
      }))
    }
    setData(oldData)
  }

  useEffect(() => {
    getHealth()
  }, [])

  function jump(url: string) {
    Taro.navigateTo({url})
  }

  return (
    <View className={styles.feature}>
      <Swiper nextMargin='30px' style={{height: '205px'}}>
        {
          data.map(d => <SwiperItem key={d.title}>
            <View className={styles.featureTitle} onClick={() => jump(d.url)}>{d.title}</View>
            {
              d.data.map(c => <View className='flex mb-3' key={c.id} onClick={() => jump(d.detailsUrl + c.id)}>
                <Image src={c.imageUrl} className={styles.featureImage}/>
                <View>
                  <View>{c.title}</View>
                  <View className='font-26 mt-1 text-muted'>{c.description}</View>
                </View>
              </View>)
            }
          </SwiperItem>)
        }
      </Swiper>
    </View>
  )
}
export default FeatureRecommended
